# Lab6Demo


[![image](https://img.shields.io/pypi/v/lab6demo.svg)](https://pypi.python.org/pypi/lab6demo)


**A python package for interactive mapping**


-   Free software: MIT license
-   Documentation: https://crose26.github.io/lab6demo
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
